@@ -8,13 +8,21 @@ class ContinueIteration(Exception):
 
 
 class BadBatchError(ContinueIteration):
-    """Use case: current batch of data is corrupted, skip current batch and fetch a new batch and then continue."""
+    """
+    Use case:
 
-    pass
+    current batch of data is corrupted, skip current batch and fetch a new batch
+    and then continue.
+    """
 
 
 class StopEngine(BreakIteration):
-    """Use case: when raised at batch iteration level, if `shutdown_engine=True` then reraise BreakIteration to terminate engine."""
+    """
+    Use case:
+
+    when raised at batch iteration level, if `shutdown_engine=True` then reraise
+    BreakIteration to terminate engine.
+    """
 
     def __init__(self):
         super().__init__(True)
